import sqlite3
import json
import logging
from iploader.readConfig import Reader

reader = Reader()


class DB:
    logging.basicConfig(filename=reader.log_destination,
                        filemode='a', format='%(asctime)s- %(levelname)s - %(message)s', datefmt='%d-%b-%y %H:%M:%S',
                        level=logging.INFO)
    
    def __init__(self):
        
        try:
            with sqlite3.connect(reader.dbpath) as conn:
                command = 'create table if not exists ip_addresses ( id INTEGER PRIMARY KEY , ' \
                          'ip STRING NOT NULL,' \
                          'date_added STRING NOT NULL)'
                command2 = 'create table if not exists abused_address (  ' \
                           'ip STRING NOT NULL,' \
                           'countryCode STRING ,' \
                           'isp STRING ,' \
                           'domain STRING ,' \
                           'totalReports STRING ,' \
                           'lastReportedAt STRING )'
                
                conn.execute(command)
                conn.execute(command2)
        except BaseException as exp:
            logging.error(f"{exp}")
            logging.error(f"{type(exp)}")
    
    @staticmethod
    def insert_data(ips):
        ips = json.loads(ips)
        with sqlite3.connect(reader.dbpath) as conn:
            command = "INSERT INTO ip_addresses VALUES(?,?,?) "
            for ip in ips:
                conn.execute(command, tuple(ip.values()))
            conn.commit()
        logging.info("New IPs inserted to DB...")
        print("New IPs inserted to DB...")
    @staticmethod
    def insert_abused(ips):
        ips = json.loads(ips)
        with sqlite3.connect(reader.dbpath) as conn:
            command = "INSERT INTO abused_address VALUES(?,?,?,?,?,?) "
            for ip in ips:
                conn.execute(command, tuple(ip.values()))
            conn.commit()
        logging.info("New IPs inserted to Abused Table...")
        print("New IPs inserted to Abused Table...")

    @staticmethod
    def insert_expired_data(ips):
        ips = json.loads(ips)
        with sqlite3.connect(reader.dbpath) as conn:
            command = "INSERT INTO expired_addresses VALUES(?,?,?) "
            for ip in ips:
                conn.execute(command, tuple(ip.values()))
            conn.commit()
    
    @staticmethod
    def get_ips():
        ip_list = []
        with sqlite3.connect(reader.dbpath) as conn:
            logging.info("Reading db to get existing ips")
            command = "SELECT * FROM ip_addresses"
            cursor = conn.execute(command)
            for row in cursor:
                ip_list.append(row[1])
            
            return ip_list
    
    @staticmethod
    def get_data():
        # ip_list = []
        with sqlite3.connect(reader.dbpath) as conn:
            # logging.info("reading existing database info to get full IP Lists using SELECT * FROM ip_addresses ")
            command = "SELECT * FROM ip_addresses"
            cursor = conn.execute(command)
            rows = cursor.fetchall()
            return rows
    
    @staticmethod
    def get_id():
        try:
            with sqlite3.connect(reader.dbpath) as conn:
                command = "SELECT id from ip_addresses ORDER by id DESC"
                cursor = conn.execute(command)
                rows = cursor.fetchone()
                if rows is None:
                    logging.info("Got row numbers from DB = 0 rows")
                    print("Got row numbers from DB = 0 rows")
                    return 0
                else:
                    index = list(rows).pop()
                    logging.info(f"Got row numbers from DB = {index} rows")
                    print(f"Got row numbers from DB = {index} rows")
                    return index
        except BaseException as exp:
            logging.error(f"{exp}")
            logging.error(f"{type(exp)}")



import requests
import json
from iploader.readConfig import Reader

reader = Reader()
KEY = reader.token


class Abuse:
    
    @staticmethod
    def send_req(ip):
        print(f"Checking {ip.strip()} against Abuse DB")
        url = 'https://api.abuseipdb.com/api/v2/check'
        querystring = {
            'ipAddress': ip
        }
        headers = {
            'Accept': 'application/json',
            'Key': KEY
        }
        response = requests.request(method='GET', url=url, headers=headers, params=querystring)
        if response.headers['X-RateLimit-Remaining'] == 0 or response.status_code == 429:
            print("Rate Limiting reached. Got 429 error!")
            exit()
        response = json.loads(response.text)
        try:
            if response['errors'] is not None:
                return None
        except BaseException as exp:
            print(exp)
        if response['data']['isWhitelisted'] is False \
                and response['data']['abuseConfidenceScore'] == 100 \
                and response['data']['totalReports'] > 0:
            
            result = dict({"ip": ip, "countryCode": response['data']['countryCode'], "isp": response['data']['isp'],
                           "domain": response['data']['domain'],
                           "totalReports": str(response['data']['totalReports']),
                           "lastReportedAt": response['data']['lastReportedAt']})
            print(f"{ip.strip()} -> Abused")
            
            return result
        
        else:
            print(f"{ip.strip()} -> OK")
            return None

# abuse = Abuse()
# print (abuse.send_req("1.1.1.1"))



import json
import logging
from datetime import datetime
from pathlib import Path

from iploader.AbuseCheck import Abuse
from iploader.database import DB
from iploader.readConfig import Reader

reader = Reader()


class File:
    ip_list = []

    logging.basicConfig(filename=reader.log_destination,
                        filemode='a', format='%(asctime)s- %(levelname)s - %(message)s', datefmt='%d-%b-%y %H:%M:%S',
                        level=logging.INFO)

    def __init__(self, file_location):
        self.file_location = file_location

    def read_data(self):
        abuse = Abuse()
        abuse_list = []
        db = DB()
        path = Path(self.file_location)
        counter = 0
        if path.exists():
            logging.info(f"Found file in {self.file_location} , reading ...")
            print(f"Found file in {self.file_location} , reading ...")
            try:
                with open(self.file_location) as ips:
                    for ip in ips:
                        abuse_result = abuse.send_req(ip)
                        if abuse_result is not None:
                            logging.info(f"{ip.strip()} -> Keep")
                            print(f"{ip.strip()} -> Keep")
                            self.ip_list.append(ip.strip())
                            counter = counter + 1
                            abuse_list.append(abuse_result)
                        else:
                            logging.info(
                                f"{ip.strip()} -> Removed from bad IP list")
                            print(f"{ip.strip()} -> Removed from bad IP list")
                    db.insert_abused(json.dumps(abuse_list))
            except BaseException as exp:
                logging.error(f"{exp}")
                logging.error(f"{type(exp)}")

            logging.info(f"Found  {counter} ips")
            return self.ip_list
        else:
            logging.error(f"file {self.file_location} does not exist .")
            print("file does not exist .")
            return None

    @staticmethod
    def convert(ips):
        db = DB()
        ip_list = []
        id_db = db.get_id()
        dt = datetime.today().strftime('%b %d %Y %I:%M%p')
        try:
            for ip in ips:
                id_db = id_db + 1
                ip_dict = {"id": id_db, "ip": ip.strip(), "date_added": dt}
                ip_list.append(ip_dict)
        except BaseException as exp:
            logging.error(f"{exp}")
            logging.error(f"{type(exp)}")
        return json.dumps(ip_list)



from iploader.file import File
from iploader.database import DB
from pathlib import Path
import datetime
import logging
from iploader.readConfig import Reader

reader = Reader()


class Compare:
    logging.basicConfig(filename=reader.log_destination,
                        filemode='a', format='%(asctime)s- %(levelname)s - %(message)s', datefmt='%d-%b-%y %H:%M:%S',
                        level=logging.INFO)
    
    @staticmethod
    def do_compare(file_location):
        try:
            path = Path(file_location)
            if path.exists():
                file = File(file_location)
                db = DB()
                file_ips = (file.read_data())
                db_ips = db.get_ips()
                unique_ips = list(set(file_ips) - set(db_ips))
                if len(unique_ips) == 0:
                    return None
                else:
                    return file.convert(unique_ips)
            else:
                logging.error(f"{reader.infile} doesn't exist")
                return None
        except BaseException as exp:
            print(exp)
    
    @staticmethod
    def do_compare_expire(ips):
        db = DB()
        db_ip_list = []
        db_ips = db.get_data()
        for db_ip in db_ips:
            db_ip_list.append(db_ip[1])
        
        diff = list(set(db_ip_list) - set(ips))
        
        return diff
    
    @staticmethod
    def get_expired_ips():
        db = DB()
        data = db.get_data()
        today = datetime.datetime.now()
        dead_line = datetime.timedelta(days=int(reader.expiration_days))
        earlier = today - dead_line
        expired_ips = []
        for i in data:
            date_time_str = (i[2])
            date_time_obj = datetime.datetime.strptime(date_time_str, '%b %d %Y %I:%M%p')
            if earlier.date() >= date_time_obj.date():
                expired_ips.append(i[1])
        return expired_ips



import setuptools

#from pip._internal.req import piarse_requirements

#reqs = [str(ir.req) for ir in parse_requirements('requirements.txt', session='hack')]

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="iploader",
    version="1.0.3",
    author="Amir Amiri",
    author_email="Amiri83@gmail.com",
    description="AbuseIPDB Ip Checker",
    scripts= ['bin/iploader',],
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Amiri83/IPloader",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)



import configparser
from pathlib import Path

path = Path('/opt/config.ini')
if path.exists() is False:
    print("Config File \"/opt/config.ini\" does not exist.\nAborting program ...")
    exit(1)

config = configparser.ConfigParser()
config.read('/opt/config.ini')


class Reader:

    def __init__(self):
        self.__token = config['conf']['Token']
        self.__infile = config['conf']['Infile']
        self.__outfile = config['conf']['Outfile']
        self.__dbpath = config['conf']['DBPath']
        self.__expiration_days = config['conf']['ExpirationDays']
        self.__log_destination = config['conf']['LogDest']


    @property
    def infile(self):
        return self.__infile

    @property
    def outfile(self):
        return self.__outfile
    
    @property
    def dbpath(self):
        return self.__dbpath

    @property
    def expiration_days(self):
        return self.__expiration_days

    @property
    def log_destination(self):
        return self.__log_destination

    @property
    def token(self):
        return self.__token

